% Check_Input_Errors.m
% Jason Wu 07/31/14

% This script checks in the input parameters for errors prior to running
% the simulation.

errFlag = 0;

%% File naming errors
if isempty(Identifier)
    disp('**ERROR** The field "Identifier" is empty')
    errFlag = 1;
    return
end

%% Flag errors
if ~(isnumeric(OverwriteAllFlag) || islogical(OverwriteAllFlag)) || ...
        OverwriteAllFlag ~= 0 && OverwriteAllFlag ~= 1
    disp('**ERROR** The field "OverwriteAllFlag" must have a value of 0 or 1');
    errFlag = 1;
    return
end

if ~(isnumeric(OverwriteOpenSHAFlag) || islogical(OverwriteOpenSHAFlag)) || ...
        OverwriteOpenSHAFlag ~= 0 && OverwriteOpenSHAFlag ~= 1
    disp('**ERROR** The field "OverwriteOpenSHAFlag" must have a value of 0 or 1');
    errFlag = 1;
    return
end

if ~(isnumeric(OverwriteGMSimsFlag) || islogical(OverwriteGMSimsFlag)) || ...
        OverwriteGMSimsFlag ~= 0 && OverwriteGMSimsFlag ~= 1
    disp('**ERROR** The field "OverwriteGMSimsFlag" must have a value of 0 or 1');
    errFlag = 1;
    return
end

if ~(isnumeric(SuppressMessagesFlag) || islogical(SuppressMessagesFlag)) || ...
        SuppressMessagesFlag ~= 0 && SuppressMessagesFlag ~= 1
    disp('**ERROR** The field "SuppressMessagesFlag" must have a value of 0 or 1');
    errFlag = 1;
    return
end

if ~(isnumeric(DefineVs30Flag) || islogical(DefineVs30Flag)) || ...
        DefineVs30Flag ~= 0 && DefineVs30Flag ~= 1
    disp('**ERROR** The field "DefineVs30Flag" must have a value of 0 or 1');
    errFlag = 1;
    return
end

if ~(isnumeric(DefineConstVs30Flag) || islogical(DefineConstVs30Flag)) || ...
        DefineConstVs30Flag ~= 0 && DefineConstVs30Flag ~= 1
    disp('**ERROR** The field "DefineConstVs30Flag" must have a value of 0 or 1');
    errFlag = 1;
    return
end

if ~(isnumeric(RandomFieldFlag) || islogical(RandomFieldFlag)) || ...
        ~ismember(RandomFieldFlag,1:5)
    disp('**ERROR** The field "RandomFieldFlag" must have a value of 1, 2, or 3');
    errFlag = 1;
    return
end

%% Random field parameter errors
if ~isnumeric(Spectral_scale) || Spectral_scale <= 0
    disp('**ERROR** The field "Spectral_scale" must be a positive integer')
    errFlag = 1;
    return
end

if ~(isnumeric(Sequential_useCoarse) || islogical(Sequential_useCoarse)) || ...
        Sequential_useCoarse ~= 0 && Sequential_useCoarse ~= 1
    disp('**ERROR** The field "Sequential_useCoarse" must have a value of 0 or 1');
    errFlag = 1;
    return
end

if ~isnumeric(Sequential_coarseSize) || Sequential_coarseSize <= 0
    disp('**ERROR** The field "Sequential_coarseSize" must be a positive integer')
    errFlag = 1;
    return
end

if ~isnumeric(Sequential_maxDist) || Sequential_maxDist < 0
    disp('**ERROR** The field "Sequential_maxDist" must be a positive number')
    errFlag = 1;
    return
end

if ~isnumeric(Sequential_maxScreen) || Sequential_maxScreen <= 0
    disp('**ERROR** The field "Sequential_maxScreen" must be a positive integer')
    errFlag = 1;
    return
end

%% Ground motion parameter errors
if ~isnumeric(Define_ERF) || ~ismember(Define_ERF,1:4)
    disp('**ERROR** The field "Define_ERF" must have a value of 1, 2, 3, or 4')
    errFlag = 1;
    return
end

if ~isnumeric(BGSeis) || ~ismember(BGSeis,1:3)
    disp('**ERROR** The field "BGSeis" must have a value of 1, 2, or 3')
    errFlag = 1;
    return
end

if ~isnumeric(AttenuationChoices) || sum(ismember(AttenuationChoices,1:10)) ~= length(AttenuationChoices)
    disp('**ERROR** The field "AttenuationChoices" must have an integer value between 1 and 10')
    errFlag = 1;
    return
end

if ~isnumeric(IntensityChoices) || sum(ismember(IntensityChoices,1:3)) ~= length(IntensityChoices)
    disp('**ERROR** The field "IntensityChoices" must have a value of 1, 2, or 3')
    errFlag = 1;
    return
end

for i = 1:length(SAPeriod)
    if ~ischar(SAPeriod{i}) || ...
        isempty(str2double(SAPeriod{i})) || ...
        str2double(SAPeriod{i}) < 0
        disp('**ERROR** The field "SAPeriod" must be a cell containing valid SA periods as strings')
        errFlag = 1;
        return
    end
end

if ~isnumeric(LongBoundLeft) || ~isnumeric(LongBoundRight) || ...
    abs(LongBoundLeft) > 180 || abs(LongBoundRight) > 180 || LongBoundLeft > LongBoundRight
    disp('**ERROR** Inappropriate longitudinal bounds (LongBoundLeft and/or LongBoundRight)')
    errFlag = 1;
    return
end

if ~isnumeric(LatBoundBot) || ~isnumeric(LatBoundTop) || ...
    abs(LatBoundBot) > 180 || abs(LatBoundTop) > 180 || LatBoundBot > LatBoundTop
    disp('**ERROR** Inappropriate latitudinal bounds (LatBoundBot and/or LatBoundTop)')
    errFlag = 1;
    return
end

if ~isnumeric(GridSpacing) || GridSpacing < 0
    disp('**ERROR** The field "GridSpacing" must be a positive number')
    errFlag = 1;
    return
end

if ~isnumeric(nSimBatches) || nSimBatches < 0
    disp('**ERROR** The field "nSimBatches" must be a positive integer')
    errFlag = 1;
    return
end

if ~isnumeric(ConstVs30) || ConstVs30 <= 0
    disp('**ERROR** The field "ConstVs30" must be a positive number')
    errFlag = 1;
    return
end



% Pending 
% if ~isnumeric(CaseNum) || ~isempty(CaseNum(CaseNum<0))
%     disp('**ERROR** The field "CaseNum" must be a numeric vector containing positive integers')
%     errFlag = 1;
%     return
% end
% RewriteEPAFlag
% ConvertMaterialFlag
% RRLimit
